pub struct FileStore { /* private fields */ }Expand description
A file store that implements the Store trait
Maze objects are stored on disk as files named <name>.json (in the working directory), with the id
of the object assumed to be the file name
Implementations
Sourceimpl FileStore
impl FileStore
Sourcepub fn new(config: &FileStoreConfig) -> Self
pub fn new(config: &FileStoreConfig) -> Self
Creates a new file store instance
Returns
A new file store instance if successful
Examples
Try to create a new maze within a file store
use data_model::{Maze, User};
use storage::{FileStore, FileStoreConfig, MazeStore, Store, Error, UserStore};
let grid: Vec<Vec<char>> = vec![
vec!['S', ' ', 'W'],
vec![' ', 'F', 'W']
];
let mut maze_to_create = Maze::from_vec(grid);
maze_to_create.name = "maze_1".to_string();
// Create the file store
let mut store = FileStore::new(&FileStoreConfig::default());
// Locate the owner by username
let find_user_result: Result<User, Error> = store.find_user_by_name("a_username");
let owner = match find_user_result {
Ok(user) => user,
Err(error) => {
println!("Error fetching user: {:?}", error);
return ;
}
};
// Create a maze within the file store
match store.create_maze(&owner, &mut maze_to_create) {
Ok(_) => {
println!(
"Successfully created maze in the file store with id = {}",
maze_to_create.id
);
}
Err(error) => {
println!(
"Failed to create maze => {}",
error
);
}
}pub fn get_mazes_dir(&self, owner: &User) -> String